error (BCP command)
===================

This is a command used to convey error messages back to the origin of a command.

Origin
------
Pin controller or media controller

Parameters
----------

message
~~~~~~~

Type: ``string``

The error message.

command
~~~~~~~

Type: ``string``

The command that was invalid and caused the error.

Response
--------
None

